
#include <iostream>
#include <cstdio>
#include <iomanip>
#include <vector>

#include "badDFT2.h"

using namespace std;
/*
void print2D(string name, float* mm, int nx, int ny){
	cout << name << ":" << endl;
  for (int j=0; j<ny; j++){ 
		for (int i=0; i<nx; i++) 
			cout << setw(6) << mm[nx*j + i];
		cout << endl;
	}
	cout << endl;

  return;
}
*/
bool saveField( Ipp64f *ff, int sX, int sY,
               const char *name, const char *mode ){
	FILE *file = fopen( name, mode );	// Saves kernels
	if ( file == NULL )  {
    cout << "Couldn't open your file, sorry!" << endl;
    return false;
  }
	for(int i = 0; i<sY; i++){
		for(int j = 0; j<sX; j++)
			fprintf(file, "%2.8f\t", ff[i*sX + j]);
		fprintf(file, "\n");
	}
	fclose(file);

	return true;
}
//---------------------------------------------------------------------
void main1D( const char* filename, int sel, bool verbose ){
	int tMax, nFields;//, sFieldX, sFieldY;
	BAD::badDFT2 d1( filename );	// create a dynamic field object
	//cout << "Size F0: " << d1.fieldList[0].sizeF << flush;
	//return;
	
	nFields = d1.nFields;				// number of the fields
	tMax = d1.tMax;							// time of simulation

	cout << endl << "Initializing stimuli... ";
	vector<Ipp64f*> stimuli;				// will store stimuli for each field
	stimuli.resize( nFields );
	for(int i=0; i<nFields; i++){
//		int f0size = d1.fieldList[i].sizeF;
		stimuli[i] = ippsMalloc_64f( d1.fieldList[i].sizeF );
		ippsZero_64f( stimuli[i], d1.fieldList[i].sizeF );	
	}
//	int f0size = d1.fieldList[0].sizeF;
	d1.fieldList[0].tools->gauss1D( 6.0, 45.0, 5.0, d1.fieldList[0].sizeF );
	ippsCopy_64f( d1.fieldList[0].tools->bufferS, stimuli[0], 
								d1.fieldList[0].sizeF );
	cout << "done" << endl;

	saveField( stimuli[0], d1.fieldList[0].sizeF, 1, "stim0.txt", "w" );
	d1.saveKernels( "myKernels.txt" );
//	tbb::tick_count tStart = tbb::tick_count::now();
	if(verbose){
		FILE *fileU = fopen( "dftUU.txt", "w" );	// Saves kernels
		FILE *fileV = fopen( "dftVV.txt", "w" );	// Saves kernels
		FILE *fileM = fopen( "dftMM.txt", "w" );	// Saves kernels
		switch(sel){
			case 1:{	// 1D[Exc+Inh] "dft1D1L.cfg"
				for(int t = 0; t<tMax; t++){
					for(int i=0; i<d1.fieldList[0].sizeF; i++)
						fprintf(fileU, "%2.8f\t", d1.fieldList[0].data[i]);
					fprintf(fileU, "\n");
					if( t==99 ){
						d1.fieldList[0].tools->gauss1D( 6.0, -10.0, 5.0, 
																					d1.fieldList[0].sizeF );
						ippsCopy_64f( d1.fieldList[0].tools->bufferS, stimuli[0], 
													d1.fieldList[0].sizeF );
					}
					//cout << setw(3) << left << setfill(' ') << t+1 << "  ";
					d1.dftStep( stimuli );
				}
				break;
      }
			case 2:{	// 1D[Exc+Inh <-> LTM] "dft1D1Lm.cfg"
				for(int t = 0; t<tMax; t++){
					for(int i=0; i<d1.fieldList[0].sizeF; i++){
						fprintf(fileU, "%2.8f\t", d1.fieldList[0].data[i]);
						fprintf(fileM, "%2.8f\t", d1.fieldList[1].data[i]);
					}
					fprintf(fileU, "\n");	fprintf(fileM, "\n");
					if( t == 99 ){
						d1.fieldList[0].tools->gauss1D( 6.0, -10.0, 5.0, d1.fieldList[0].sizeF );
						ippsCopy_64f( d1.fieldList[0].tools->bufferS, stimuli[0], 
													d1.fieldList[0].sizeF );
					}
	//				cout << setw(3) << left << setfill(' ') << t+1 << ": ";
					d1.dftStep( stimuli );
	//				cout << endl;
				}
				break;
      }
			case 3:{	// 1D[Exc] <-> 1D[Inh] "dft1D2L.cfg"
				for(int t = 0; t<tMax; t++){
					for(int i=0; i<d1.fieldList[0].sizeF; i++){
						fprintf(fileU, "%2.8f\t", d1.fieldList[0].data[i]);
						fprintf(fileV, "%2.8f\t", d1.fieldList[1].data[i]);
					}
					fprintf(fileU, "\n");	fprintf(fileV, "\n");
					if( t == 99 ){
						d1.fieldList[0].tools->gauss1D( 6.0, -10.0, 5.0, d1.fieldList[0].sizeF );
						ippsCopy_64f( d1.fieldList[0].tools->bufferS, stimuli[0], 
													d1.fieldList[0].sizeF );
					}
					//cout << setw(3) << right << setfill(' ') << t+1 << ": ";
					d1.dftStep( stimuli );
				}
				break;
      }
			case 4:{	// 1D[Exc <-> LTM] <-> 1D[Inh] "dft1D2Lm.cfg"
				for(int t = 0; t<tMax; t++){
					for(int i=0; i<d1.fieldList[0].sizeF; i++){
						fprintf(fileU, "%2.8f\t", d1.fieldList[0].data[i]);
						fprintf(fileV, "%2.8f\t", d1.fieldList[1].data[i]);
						fprintf(fileM, "%2.8f\t", d1.fieldList[2].data[i]);
					}
					fprintf(fileU, "\n");	fprintf(fileV, "\n");	fprintf(fileM, "\n");
					if( t == 99 ){
						d1.fieldList[0].tools->gauss1D( 6.0, -10.0, 5.0, d1.fieldList[0].sizeF );
						ippsCopy_64f( d1.fieldList[0].tools->bufferS, stimuli[0], 
													d1.fieldList[0].sizeF );
					}
					d1.dftStep( stimuli );
				}
				break;
      }
			case 5:{	// 1D[Exc+Inh] <-> 2D[Exc+Inh] "dft1Dto2D.cfg"
				FILE *file1Da = fopen( "f1Da.txt", "w" );	// Saves kernels
				FILE *file1Db = fopen( "f1Db.txt", "w" );	// Saves kernels
				int sFieldX = d1.fieldList[1].dimList[0].sizeD;
				int sFieldY = d1.fieldList[1].dimList[1].sizeD;
				d1.fieldList[2].tools->gauss1D( 5.0, 10.0, 4.0, sFieldY );
				ippsCopy_64f( d1.fieldList[2].tools->bufferS, stimuli[2], sFieldY );
				saveField( stimuli[2], sFieldY, 1, "stim2.txt", "w" );
				for(int t = 0; t<tMax; t++){
					for(int i=0; i<d1.fieldList[0].sizeF; i++){
						fprintf(file1Da, "%2.8f\t", d1.fieldList[0].data[i]);
						fprintf(file1Db, "%2.8f\t", d1.fieldList[2].data[i]);
					}
					fprintf(file1Da, "\n");	fprintf(file1Db, "\n");
					if(t==95) 
						saveField( d1.fieldList[1].data, sFieldX, sFieldY, "f2D95.txt", "w");
					if(t==110) 
						saveField( d1.fieldList[1].data, sFieldX, sFieldY, "f2D110.txt", "w");
					if( t == 99 ){
						d1.fieldList[0].tools->gauss1D( 6.0, -10.0, 5.0, 
																					d1.fieldList[0].sizeF );
						ippsCopy_64f( d1.fieldList[0].tools->bufferS, stimuli[0], 
													d1.fieldList[0].sizeF );
					}
					//cout << setw(3) << right << setfill(' ') << t+1 << ": ";
					d1.dftStep( stimuli );
				}
				fclose(file1Da);	fclose(file1Db);
				break;
      }
			case 6:{	// [1DExc<->1DInh] <-> 1D[Exc](CoS) "dft1D_seq.cfg"
				int sFieldX = d1.fieldList[0].dimList[0].sizeD;
				ippsZero_64f( stimuli[0], d1.fieldList[0].sizeF );
				Ipp64f *inputUU = ippsMalloc_64f( sFieldX );
				d1.fieldList[0].tools->gauss1D( 1.0, 72.0, 5.0, sFieldX );
				ippsCopy_64f( d1.fieldList[0].tools->bufferS, inputUU, sFieldX );
				d1.fieldList[0].tools->gauss1D( 1.0, 144.0, 5.0, sFieldX );
				ippsAdd_64f_I( d1.fieldList[0].tools->bufferS, inputUU, sFieldX );
				d1.fieldList[0].tools->gauss1D( 1.0, 216.0, 5.0, sFieldX );
				ippsAdd_64f_I( d1.fieldList[0].tools->bufferS, inputUU, sFieldX );
				d1.fieldList[0].tools->gauss1D( 1.0, 288.0, 5.0, sFieldX );
				ippsAdd_64f_I( d1.fieldList[0].tools->bufferS, inputUU, sFieldX );
				//saveField( inputUU, sFieldX, 1, "dftInp0.txt", "w" );
        
				Ipp32f *conn_weights = ippsMalloc_32f( d1.sSequence*sFieldX );
				ippsZero_32f( conn_weights, d1.sSequence*sFieldX );	
				ippsSet_32f( 1, conn_weights + 0*sFieldX + 211, 10 );
				ippsSet_32f( 1, conn_weights + 1*sFieldX + 67, 10 );
				ippsSet_32f( 1, conn_weights + 2*sFieldX + 283, 10 );
				ippsSet_32f( 1, conn_weights + 3*sFieldX + 139, 10 );
				//saveField( conn_weights, sFieldX, d1.sSequence, "dftConnW.txt", "w" );
        
				for(int t = 0; t<tMax; t++){
					//saveField( d1.fieldList[2].data, sFieldX, 1, "dftCoS.txt", "a" );
					//cout << setw(3) << left << setfill(' ') << t+1 << ": ";
					for(int i=0; i<d1.fieldList[0].sizeF; i++){
						fprintf(fileU, "%2.8f\t", d1.fieldList[0].data[i]);
						fprintf(fileV, "%2.8f\t", d1.fieldList[1].data[i]);
						fprintf(fileM, "%2.8f\t", d1.fieldList[2].data[i]);
					}
					fprintf(fileU, "\n");	fprintf(fileV, "\n");	fprintf(fileM, "\n");
					// ------------ do a sequence step -------------
					if( t>50 ) d1.seqStep( &d1.fieldList[2], 0, conn_weights ); 
					else d1.seqStep( &d1.fieldList[2], 2, conn_weights );
					// --------- do a dynamic field step -----------
					ippsMulC_64f_I( 6.0, d1.bufferL, sFieldX );
					ippsAdd_64f( inputUU, d1.bufferL, stimuli[0], sFieldX );
          
					d1.dftStep( stimuli );
					//cout << endl;
				}
				ippsFree ( conn_weights );
				ippsFree ( inputUU );
        
				break;
			}
		}
		fclose(fileU);		fclose(fileV);			fclose(fileM);
	}else{
		/* ------------ Main loop, no output ------------ */
		for(int t = 0; t<tMax; t++){
			if((t+1)%10 == 0) 	cout << "." << flush;
			if((t+1)%100 == 0)	cout << " " << t+1 << endl;
//      cout << setw(3) << right << t+1 << ": ";
			if( t == 99 ){
				d1.fieldList[0].tools->gauss1D( 6.0, -10.0, 5.0, d1.fieldList[0].sizeF );
				ippsCopy_64f( d1.fieldList[0].tools->bufferS, stimuli[0], 
											d1.fieldList[0].sizeF );
			}
			d1.dftStep( stimuli );
//      cout << endl;
		}
	}
//	tbb::tick_count tEnd = tbb::tick_count::now();
//	cout << "Time(TBB): " << 1000*(tEnd-tStart).seconds() 
//			 << " mseconds." << endl;
	//cout << "Average convolution time: " << d1.tSum/tMax << endl;

	for(int i=0; i<nFields; i++)
		ippsFree ( stimuli[i] );

	return;
}

void main2D( const char* filename, int sel, bool verbose ){
	int tMax, sFieldX, sFieldY, nFields;
	BAD::badDFT2 d1( filename );	// create a dynamic field object
	//saveField( d1.fieldList[0].kernelList[2].dataKe, 
						 //d1.fieldList[0].kernelList[0].sizeK[0],
						 //d1.fieldList[0].kernelList[1].sizeK[0], 
						 //"kernel2De.txt", "w" );
	//saveField( d1.fieldList[0].kernelList[2].dataKi, 
						 //d1.fieldList[0].kernelList[0].sizeK[1],
						 //d1.fieldList[0].kernelList[1].sizeK[1], 
						 //"kernel2Di.txt", "w" );
	//return;
	
	sFieldX = d1.fieldList[0].dimList[0].sizeD;	// size of the field (X dimension)
	sFieldY = d1.fieldList[0].dimList[1].sizeD;	// size of the field (Y dimension)
	nFields = d1.nFields;				// number of the fields
	tMax = d1.tMax;							// time of simulation

	cout << endl << "Initializing stimuli... ";
	vector<Ipp64f*> stimuli;				// will store stimuli for each field
	stimuli.resize( nFields );
	for(int i=0; i<nFields; i++){
		stimuli[i] = ippsMalloc_64f( d1.fieldList[i].sizeF );
		ippsZero_64f( stimuli[i], d1.fieldList[i].sizeF );	
	}
/* ------- create a noisy 2D input ------
	unsigned int mySeed = 0;
	ippsRandGauss_Direct_32f( stimuli[0], d1.fieldList[0].sizeF, 0, 1, &mySeed );
	ippsMulC_32f_I( 5.0, stimuli[0], d1.fieldList[0].sizeF ); 
*/
	d1.fieldList[0].tools->gauss2D( 5.0, 30.0, 5.0, -10.0, 5.0 );
	ippsCopy_64f( d1.fieldList[0].tools->bufferM, stimuli[0], 
								d1.fieldList[0].sizeF );
	cout << "done" << endl;
	
//	saveField( stimuli[0], sFieldX, sFieldY, "stim0.txt", "w" );
	d1.saveKernels( "myKernels.txt" );
	cout << endl << "Starting the simulation ..." << endl;
//	tbb::tick_count tStart = tbb::tick_count::now();
	if(verbose){
		switch (sel){
			case 7:{	// 2D[Exc+Inh] "dft2D1L.cfg"
				for(int t = 0; t<tMax; t++){
					if(t==95) saveField( d1.fieldList[0].data, sFieldX, sFieldY, "f2D95.txt", "w");
					if(t==110) saveField( d1.fieldList[0].data, sFieldX, sFieldY, "f2D110.txt", "w");
					if( t==99 ){
						d1.fieldList[0].tools->gauss2D( 5.0, -10.0, 5.0, 20.0, 5.0 );
						ippsCopy_64f( d1.fieldList[0].tools->bufferM, stimuli[0], 
													d1.fieldList[0].sizeF );
					}
					d1.dftStep( stimuli );
				}
				break;
      }
			case 8:{	// 2D[Exc+Inh <-> LTM] "dft2D1Lm.cfg"
				for(int t = 0; t<tMax; t++){
					if(t==95){
						saveField( d1.fieldList[0].data, sFieldX, sFieldY, "f2D95.txt", "w");
						saveField( d1.fieldList[1].data, sFieldX, sFieldY, "f2D95m.txt", "w");
					}
					if(t==110){
						saveField( d1.fieldList[0].data, sFieldX, sFieldY, "f2D110.txt", "w");
						saveField( d1.fieldList[1].data, sFieldX, sFieldY, "f2D110m.txt", "w");
					}
					if( t==99 ){
						d1.fieldList[0].tools->gauss2D( 5.0, -10.0, 5.0, 20.0, 5.0 );
						ippsCopy_64f( d1.fieldList[0].tools->bufferM, stimuli[0], 
													d1.fieldList[0].sizeF );
					}
					d1.dftStep( stimuli );
				}
				break;
      }
			case 9:{	// 2D[Exc+Inh] <-> 1D[Exc+Inh] "dft2Dto1D.cfg"
				FILE *fileU = fopen( "f1D.txt", "w" );
				for(int t = 0; t<tMax; t++){
					//cout << setw(3) << right << t+1 << ": ";
					for(int i=0; i<d1.fieldList[1].sizeF; i++)
						fprintf(fileU, "%2.8f\t", d1.fieldList[1].data[i]);
					fprintf(fileU, "\n");
					if(t==95) saveField( d1.fieldList[0].data, sFieldX, sFieldY, "f2D95.txt", "w");
					if(t==110) saveField( d1.fieldList[0].data, sFieldX, sFieldY, "f2D110.txt", "w");
					if( t==99 ){
						d1.fieldList[0].tools->gauss2D( 5.0, -10.0, 5.0, 20.0, 5.0 );
						ippsCopy_64f( d1.fieldList[0].tools->bufferM, stimuli[0], 
													d1.fieldList[0].sizeF );
					}
					d1.dftStep( stimuli );
					//cout << endl;
				}
				fclose(fileU);
				break;
      }
		}
	}else{
		for(int t = 0; t<tMax; t++){
			if((t+1)%10 == 0) 	cout << "." << flush;
			if((t+1)%100 == 0)	cout << " " << t+1 << endl;
			//cout << setw(3) << right << t+1 << ": ";
			if( t == 99 ){
				d1.fieldList[0].tools->gauss2D( 5.0, -10.0, 5.0, 20.0, 5.0 );
				ippsCopy_64f( d1.fieldList[0].tools->bufferM, stimuli[0], 
											d1.fieldList[0].sizeF );
			}
			d1.dftStep( stimuli );
			//cout << endl;
		}
	}
//	tbb::tick_count tEnd = tbb::tick_count::now();
//	cout << "End of the simulation." << endl << "Time(TBB): " 
//			 << 1000*(tEnd-tStart).seconds() << " mseconds." << endl;
	//cout << "Average convolution time: " << d1.tSum/tMax << endl;

	for(int i=0; i<nFields; i++)
		ippsFree ( stimuli[i] );

	return;
}

void main3D( const char* filename, int sel, bool verbose ){
	int tMax, sFieldX, sFieldY, sFieldZ, nFields;
	BAD::badDFT2 d1( filename );	// create a dynamic field object
/*
	int sKx = d1.fieldList[0].kernelList[0].sizeK[0];
	int sKy = d1.fieldList[0].kernelList[1].sizeK[0];
	int sKz = d1.fieldList[0].kernelList[2].sizeK[0];
	saveField( d1.fieldList[0].kernelList[0].dataKe, sKx, 1, "kernel3Dxe.txt", "w" );
	saveField( d1.fieldList[0].kernelList[1].dataKe, sKy, 1, "kernel3Dye.txt", "w" );
	saveField( d1.fieldList[0].kernelList[2].dataKe, sKz, 1, "kernel3Dze.txt", "w" );
	saveField( d1.fieldList[0].kernelList[3].dataKe+sKx*sKy*15, 
						 sKx, sKy, "kernel3De.txt", "w" );
	sKx = d1.fieldList[0].kernelList[0].sizeK[1];
	sKy = d1.fieldList[0].kernelList[1].sizeK[1];
	sKz = d1.fieldList[0].kernelList[2].sizeK[1];
	saveField( d1.fieldList[0].kernelList[0].dataKi, sKx, 1, "kernel3Dxi.txt", "w" );
	saveField( d1.fieldList[0].kernelList[1].dataKi, sKy, 1, "kernel3Dyi.txt", "w" );
	saveField( d1.fieldList[0].kernelList[2].dataKi, sKz, 1, "kernel3Dzi.txt", "w" );
	saveField( d1.fieldList[0].kernelList[3].dataKi+sKx*sKy*30, 
						 sKx, sKy, "kernel3Di.txt", "w" );
	return;
*/
	sFieldX = d1.fieldList[0].dimList[0].sizeD;	// size of the field (X dimension)
	sFieldY = d1.fieldList[0].dimList[1].sizeD;	// size of the field (Y dimension)
	sFieldZ = d1.fieldList[0].dimList[2].sizeD;	// size of the field (Z dimension)
	nFields = d1.nFields;				// number of the fields
	tMax = d1.tMax;							// time of simulation

	cout << endl << "Initializing stimuli... ";
	vector<Ipp64f*> stimuli;				// will store stimuli for each field
	stimuli.resize( nFields );
	for(int i=0; i<nFields; i++){
		stimuli[i] = ippsMalloc_64f( d1.fieldList[i].sizeF );
		ippsZero_64f( stimuli[i], d1.fieldList[i].sizeF );	
	}
/* ------- create a noisy 2D input ------
	unsigned int mySeed = 0;
	ippsRandGauss_Direct_32f( stimuli[0], d1.fieldList[0].sizeF, 0, 1, &mySeed );
	ippsMulC_32f_I( 5.0, stimuli[0], d1.fieldList[0].sizeF ); 
*/
	d1.fieldList[0].tools->gauss3D( 6.0, 30.0, 5.0, -10.0, 5.0, -20.0, 5.0 );
	ippsCopy_64f( d1.fieldList[0].tools->bufferL, stimuli[0], 
								d1.fieldList[0].sizeF );
	cout << "done" << endl;
	
//	saveField( stimuli[0], sFieldX, sFieldY, "stim0.txt", "w" );
	d1.saveKernels( "myKernels.txt" );
	cout << endl << "Starting the simulation..." << endl;
//	tbb::tick_count tStart = tbb::tick_count::now();
	if(verbose){
		switch (sel){
			case 10:{
				for(int t = 0; t<tMax; t++){
					if(t==19){
						saveField( d1.fieldList[0].data + sFieldX*sFieldY*70, 
															 sFieldX, sFieldY, "f3D70.txt", "w");
						saveField( d1.fieldList[0].data + sFieldX*sFieldY*57, 
															 sFieldX, sFieldY, "f3D57.txt", "w");
					
					}
					if(t==109) saveField( d1.fieldList[0].data + sFieldX*sFieldY*70, 
															 sFieldX, sFieldY, "f3D110.txt", "w");
					if( t==99 ){
						d1.fieldList[0].tools->gauss3D( 6.0, -10.0, 5.0, 20.0, 5.0, 40.0, 5.0 );
						ippsCopy_64f( d1.fieldList[0].tools->bufferL, stimuli[0], 
													d1.fieldList[0].sizeF );
					}
					d1.dftStep( stimuli );
				}
				break;
      }
			default:
				cout << "I'm doing nothing, what's the matter with u?" << endl;
		}
	}else{
		for(int t = 0; t<tMax; t++){
//			cout << "." << flush;
			if((t+1)%10 == 0) 	cout << "." << flush;
			if((t+1)%100 == 0)	cout << " " << t+1 << endl;
			//cout << setw(3) << right << t+1 << ": ";
			//if( t == 99 ){
				//d1.fieldList[0].tools->gauss3D( 5.0, -10.0, 5.0, 20.0, 5.0, 40.0, 4.0 );
				//ippsCopy_64f( d1.fieldList[0].tools->bufferL, stimuli[0], 
											//d1.fieldList[0].sizeF );
			//}
			d1.dftStep( stimuli );
			//cout << endl;
		}
	}
//	tbb::tick_count tEnd = tbb::tick_count::now();
//	cout << "End of the simulation." << endl << "Time(TBB): " 
//			 << 1000*(tEnd-tStart).seconds() << " mseconds." << endl;
	//cout << "Average convolution time: " << d1.tSum/tMax << endl;

	for(int i=0; i<nFields; i++)
		ippsFree ( stimuli[i] );

	return;
}

int main( int argc, char *argv[] ){
	//string str1 = argv[1], str2 = argv[2];
	size_t found;
	int sel;// = 7;
	bool verb = false;
	
	if( argc > 1 ){
		verb = true;
		cout << "With verbose" << endl;
	}
/**/
	cout << "===>>> BADdft2 main tester <<<===" << endl
			 << "Sample cases:" << endl 
			 << "1: 1D[Exc+Inh]\tdft1D1L.cfg" << endl
			 << "2: 1D[Exc+Inh <-> LTM]\tdft1D1Lm.cfg." << endl
			 << "3: 1D[Exc] <-> 1D[Inh]\tdft1D2L.cfg." << endl
			 << "4: 1D[Exc <-> LTM] <-> 1D[Inh]\tdft1D2Lm.cfg." << endl
			 << "5: 1D[Exc+Inh] <-> 2D[Exc+Inh]\tdft1Dto2D.cfg." << endl
			 << "6:  1D[Exc <-> Inh] <-> 1D[CoS]\tdft1D_seq.cfg." << endl
			 << "7:  2D[Exc+Inh]\tdft2D1L.cfg." << endl
			 << "8:  2D[Exc+Inh <-> LTM]\tdft2D1Lm.cfg" << endl
			 << "9:  2D[Exc+Inh] <-> 1D[Exc+Inh]\tdft2Dto1D.cfg" << endl
			 << "10: 3D[Exc+Inh]\tdft3D1L.cfg." << endl
			 << "Enter selection: ";
	cin >> sel;
	switch(sel){
		case 1:
			main1D("../tester/confFiles/dft1D1L.cfg", sel, verb );
			break;
		case 2:
			main1D("../tester/confFiles/dft1D1Lm.cfg", sel, verb );
			break;
		case 3:
			main1D("../tester/confFiles/dft1D2L.cfg", sel, verb );
			break;
		case 4:
			main1D("../tester/confFiles/dft1D2Lm.cfg", sel, verb );
			break;
		case 5:
			main1D("../tester/confFiles/dft1Dto2D.cfg", sel, verb );
			break;
		case 6:
			main1D("../tester/confFiles/dft1D_seq.cfg", sel, verb );
			break;
		case 7:
			main2D("../tester/confFiles/dft2D1L.cfg", sel, verb );
			break;
		case 8:
			main2D("../tester/confFiles/dft2D1Lm.cfg", sel, verb );
			break;
		case 9:
			main2D("../tester/confFiles/dft2Dto1D.cfg", sel, verb );
			break;
		case 10:
			main3D("../tester/confFiles/dft3D1L.cfg", sel, verb );
			break;
		default:
			cout << "Case not supported, try again!" << endl;
	}
/*	
	found = str1.find_first_of("123");
	dd = atoi(&str1[found]); 
	cout << "Dimensions: " << dd;
	if( dd == 1 ){
		found = str1.find_first_of("12", found+1);
		ll = atoi(&str1[found]);
		found = str1.find_first_of("m", found+1);
		if( int(found) > 0 )
			main1D(argv[1], ll, true, verb );
		else
			main1D(argv[1], ll, false, verb );
	}else if( dd == 2 ){
		found = str1.find_first_of("12", found+1);
		ll = atoi(&str1[found]);
		cout << "\tLayers: " << ll << endl;
		found = str1.find_first_of("m", found+1);
		if( int(found) > 0 )
			main2D(argv[1], ll, true, verb );
		else
			main2D(argv[1], ll, false, verb );	
	}
*/
	cout << "Ciao bello badDFT2" << endl;
	
	return 0;
}

